.. # ********** Please don't edit this file!
.. # ********** It has been generated automatically by dae_devops version 0.5.4.dev0+g1fb30ef.d20230527.
.. # ********** For repository_name dls-bxflow

Naming conventions
=======================================================================

Here are the naming conventions used within the source code.

variables
    lowercase, underscores

constants
    uppercase, underscores

classes
    camel case

class methods
    lowercase, underscores

imports
    require fully qualified package name (import <package> does nothing)

    exception: top-level packages __init__.py will have __version__ defined in them

python packages
    lowercase, underscores

repository
    lowercase, hyphens


.. # dae_devops_fingerprint 9d64e1bb797ab206899b7140463b1ffa
